package com.ruoyi.szxc.mapper;

import com.ruoyi.szxc.domain.SzxcBankcardInfo;

import java.util.List;

/**
 * 银行卡信息Mapper接口
 * 
 * @author hs
 * @date 2024-03-15
 */
public interface SzxcBankcardInfoMapper 
{
    /**
     * 查询银行卡信息
     * 
     * @param id 银行卡信息主键
     * @return 银行卡信息
     */
    public SzxcBankcardInfo selectSzxcBankcardInfoById(Long id);

    /**
     * 查询银行卡信息列表
     * 
     * @param szxcBankcardInfo 银行卡信息
     * @return 银行卡信息集合
     */
    public List<SzxcBankcardInfo> selectSzxcBankcardInfoList(SzxcBankcardInfo szxcBankcardInfo);

    /**
     * 新增银行卡信息
     * 
     * @param szxcBankcardInfo 银行卡信息
     * @return 结果
     */
    public int insertSzxcBankcardInfo(SzxcBankcardInfo szxcBankcardInfo);

    /**
     * 修改银行卡信息
     * 
     * @param szxcBankcardInfo 银行卡信息
     * @return 结果
     */
    public int updateSzxcBankcardInfo(SzxcBankcardInfo szxcBankcardInfo);

    /**
     * 删除银行卡信息
     * 
     * @param id 银行卡信息主键
     * @return 结果
     */
    public int deleteSzxcBankcardInfoById(Long id);

    /**
     * 批量删除银行卡信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSzxcBankcardInfoByIds(Long[] ids);

    void updateSzxcBankcardInfo2(SzxcBankcardInfo param);
}
